#!/bin/bash

shopt -s nullglob
set -ex

echo "Building for target $TARGET..."

export FORCE_UNSAFE_CONFIGURE=1

cd src
git clean -f -d

if [ ! -f ../targets/$TARGET/config ]; then
	IFS='/' read -ra OPTIONS <<< "$TARGET"
	MAIN_TARGET="${OPTIONS[0]}"
	SUB_TARGET="${OPTIONS[1]}"
	DEVICE_TARGET="${OPTIONS[2]}"
	if [ -z "$MAIN_TARGET" ]; then
		echo "No target specified. Aborting..." >&2
		exit 1
	fi
	echo "CONFIG_TARGET_${MAIN_TARGET}=y" > .config
	if [ ! -z "$SUB_TARGET" ]; then
		echo "CONFIG_TARGET_${MAIN_TARGET}_${SUB_TARGET}=y" >> .config
	fi
	if [ ! -z "$DEVICE_TARGET" ]; then
		echo "CONFIG_TARGET_${MAIN_TARGET}_${SUB_TARGET}_DEVICE_${DEVICE_TARGET}=y" >> .config
	fi
	if [ -z "$DEVICE_TARGET" ]; then
		echo "CONFIG_TARGET_MULTI_PROFILE=y" >> .config
		echo "CONFIG_TARGET_ALL_PROFILES=y" >> .config
	fi
	cat .config
else
	cp ../targets/$TARGET/config .config
fi

patches=(../targets/$TARGET/*.patch)
if [ ! -z "$patches" ]; then
	cat $patches | patch -p1
fi

make defconfig
make download
make -j$(nproc) || (make -j1 V=s >&2)

ls bin/targets/*/*

mkdir -p ../dist
outputs=(bin/targets/*/*/*.bin)
if [ ! -z "${outputs[*]}" ]; then
	cp ${outputs[*]} ../dist
else
	echo "WARNING: firmware not built likely due to exceeding flash size" >&2
fi

